/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 * @providesModule AppState
 * @flow
 */
'use strict';

function throwMissingNativeModule() {
  console.warn(
    'Cannot use AppState module when native RCTAppState is not included in the build.\n' +
    'Either include it, or check AppState.isAvailable before calling any methods.'
  );
}

class MissingNativeAppStateShim {
  // AppState
  isAvailable: boolean = false;
  currentState: ?string = null;

  addEventListener() {
    throwMissingNativeModule();
  }

  removeEventListener() {
    throwMissingNativeModule();
  }

  // EventEmitter
  addListener() {
    throwMissingNativeModule();
  }

  removeAllListeners() {
    throwMissingNativeModule();
  }

  removeSubscription() {
    throwMissingNativeModule();
  }
}

// This module depends on the native `RCTAppState` module. If you don't include it,
// `AppState.isAvailable` will return `false`, and any method calls will throw.
// We reassign the class variable to keep the autodoc generator happy.
var AppState = new MissingNativeAppStateShim();

module.exports = AppState;
