/**
 * Copyright (c) 2015-present, JD.COM.
 * All rights reserved.
 */
'use strict';

let dimensions = {
  // Not map to real window size, because that map to screen size in native env.
  window: {
    width: Math.min(document.documentElement.clientWidth, 750),
    height: document.documentElement.clientHeight,
    scale: parseInt(window.devicePixelRatio, 10) || 1,
  },
  modalFullscreenView: {
    width: Math.min(640, screen.width),
    height: screen.height
  }
};

class Dimensions {

  /**
   * Initial dimensions are set before `runApplication` is called so they should
   * be available before any other require's are run, but may be updated later.
   *
   * Note: Although dimensions are available immediately, they may change (e.g
   * due to device rotation) so any rendering logic or styles that depend on
   * these constants should try to call this function on every render, rather
   * than caching the value (for example, using inline styles rather than
   * setting a value in a `StyleSheet`).
   *
   * @param {string} dim Name of dimension as defined when calling `set`.
   * @returns {Object?} Value for the dimension.
   */
  static get(dim: string): Object {
    return dimensions[dim];
  }
}

export default Dimensions;
