/**
 * Copyright (c) 2015-present, JingDong Group Holding Limited.
 * All rights reserved.
 */
'use strict';

var chalk = require('chalk');
var path = require('path');
var fs = require('fs');
var easyfile = require('easyfile');
var webpack = require('webpack');
var config = require('./util/config');
var getRoot = require('./util/config').getRoot;
/**
 * Builds the javascript bundle.
 */
function bundle(argv) {
  copyVersion();
  process.env.NODE_ENV = process.env.NODE_ENV || 'production';
  var cliConfig = config.getCliConfig();
  var webpackConfig = config.getWebpackConfig();
  var compiler = webpack(webpackConfig);
  compiler.run(function(err, stats) {
    var options = {
      colors: true
    };
    console.log(stats.toString(options));
  });
}

function copyVersion() {
  const rootDir = getRoot();
  if(!easyfile.isFile(path.join(rootDir, 'web/version.json' ))){
    /**
     * 拷贝 version 文件至 web 目录下，并修改 moduleName
     */
    let fileName = process.cwd().split('-').pop()+'.version';
    let moduleName = process.cwd().split('-').pop();
    if(!easyfile.isFile(fileName)){
      var allfiles = fs.readdirSync(process.cwd()+'/jsbundles/');
      allfiles.forEach(function(item, index){
        if(path.extname(item) == '.version'){
          fileName = item;
          moduleName = path.basename(item,".version");
        }
      })
    }
    let sourceFile = path.join(process.cwd()+'/jsbundles/', fileName);
    let destFile = path.join(rootDir, 'web/version.json' );
    easyfile.copy(sourceFile, destFile, {
      force: true,
      backup: true,
    });

    /**
     * 修改moduleName
     */
    fs.readFile(destFile,'utf8',function (err, data) {
      if(err) console.log(err);
      var version = JSON.parse(data);
      version.moduleName = moduleName;
      var t = JSON.stringify(version);
      fs.writeFileSync(destFile,t);
    });
  }
}

module.exports = bundle;
